
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef E_UTIL_ENUMTYPES_H
#define E_UTIL_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "e-util-enums.h" */
#define E_TYPE_ACTIVITY_STATE	(e_activity_state_get_type())
GType e_activity_state_get_type	(void) G_GNUC_CONST;
#define E_TYPE_AUTOMATIC_ACTION_POLICY	(e_automatic_action_policy_get_type())
GType e_automatic_action_policy_get_type	(void) G_GNUC_CONST;
#define E_TYPE_DATE_WEEKDAY	(e_date_weekday_get_type())
GType e_date_weekday_get_type	(void) G_GNUC_CONST;
#define E_TYPE_DURATION_TYPE	(e_duration_type_get_type())
GType e_duration_type_get_type	(void) G_GNUC_CONST;
#define E_TYPE_IMAGE_LOADING_POLICY	(e_image_loading_policy_get_type())
GType e_image_loading_policy_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_INSERT_CONTENT_FLAGS	(e_content_editor_insert_content_flags_get_type())
GType e_content_editor_insert_content_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_GET_CONTENT_FLAGS	(e_content_editor_get_content_flags_get_type())
GType e_content_editor_get_content_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_NODE_FLAGS	(e_content_editor_node_flags_get_type())
GType e_content_editor_node_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_BLOCK_FORMAT	(e_content_editor_block_format_get_type())
GType e_content_editor_block_format_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_FONT_SIZE	(e_content_editor_font_size_get_type())
GType e_content_editor_font_size_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_ALIGNMENT	(e_content_editor_alignment_get_type())
GType e_content_editor_alignment_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_GRANULARITY	(e_content_editor_granularity_get_type())
GType e_content_editor_granularity_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_COMMAND	(e_content_editor_command_get_type())
GType e_content_editor_command_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_SCOPE	(e_content_editor_scope_get_type())
GType e_content_editor_scope_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_UNIT	(e_content_editor_unit_get_type())
GType e_content_editor_unit_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONTENT_EDITOR_FIND_FLAGS	(e_content_editor_find_flags_get_type())
GType e_content_editor_find_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_UNDO_REDO_STATE	(e_undo_redo_state_get_type())
GType e_undo_redo_state_get_type	(void) G_GNUC_CONST;
#define E_TYPE_DN_DTARGET_TYPE	(e_dn_dtarget_type_get_type())
GType e_dn_dtarget_type_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONFIG_LOOKUP_SOURCE_KIND	(e_config_lookup_source_kind_get_type())
GType e_config_lookup_source_kind_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CONFIG_LOOKUP_RESULT_KIND	(e_config_lookup_result_kind_get_type())
GType e_config_lookup_result_kind_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_UTIL_ENUMTYPES_H */

/* Generated data ends here */

