
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef E_MAIL_FORMATTER_ENUMTYPES_H
#define E_MAIL_FORMATTER_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "e-mail-formatter-enums.h" */
#define E_TYPE_MAIL_FORMATTER_COLOR	(e_mail_formatter_color_get_type())
GType e_mail_formatter_color_get_type	(void) G_GNUC_CONST;
#define E_TYPE_MAIL_FORMATTER_HEADER_FLAGS	(e_mail_formatter_header_flags_get_type())
GType e_mail_formatter_header_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_MAIL_FORMATTER_MODE	(e_mail_formatter_mode_get_type())
GType e_mail_formatter_mode_get_type	(void) G_GNUC_CONST;
#define E_TYPE_MAIL_FORMATTER_QUOTE_FLAGS	(e_mail_formatter_quote_flags_get_type())
GType e_mail_formatter_quote_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_MAIL_PARSER_EXTENSION_FLAGS	(e_mail_parser_extension_flags_get_type())
GType e_mail_parser_extension_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_MAIL_PART_VALIDITY_FLAGS	(e_mail_part_validity_flags_get_type())
GType e_mail_part_validity_flags_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_MAIL_FORMATTER_ENUMTYPES_H */

/* Generated data ends here */

